@@ -22,7 +22,7 @@ test_that("Simplest form of any_table", {
                     print   = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -35,7 +35,7 @@ test_that("any_table with combinations", {
                     print   = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -47,7 +47,7 @@ test_that("any_table with multiple combinations", {
                     print   = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -60,7 +60,7 @@ test_that("any_table many combinations don't break", {
                       print   = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -74,7 +74,7 @@ test_that("any_table with titles and footnotes", {
                     print     = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -131,7 +131,7 @@ test_that("any_table with a lot of statistics doesn't break", {
                       print      = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -145,7 +145,7 @@ test_that("any_table with interleaved order", {
                       print      = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
 })
 
 
@@ -351,7 +351,18 @@ test_that("any_table with pre summarised data", {
                  print      = FALSE))
 
     expect_type(result_list, "list")
-    expect_equal(length(result_list), 2)
+    expect_equal(length(result_list), 3)
+})
+
+
+test_that("any_table with no column variables", {
+    result_list <- suppressMessages(dummy_df |>
+           any_table(rows    = "age",
+                     values  = weight,
+                     print   = FALSE))
+
+    expect_type(result_list, "list")
+    expect_equal(length(result_list), 3)
 })
 
 ###############################################################################
@@ -394,24 +405,6 @@ test_that("any_table aborts with no valid row variables", {
 })
 
 
-test_that("any_table aborts with no valid column variables", {
-    expect_message(result_list <- dummy_df |>
-           any_table(rows    = "age",
-                     columns = "",
-                     values  = weight,
-                     print   = FALSE), " X ERROR: No valid column variables provided")
-})
-
-
-test_that("any_table aborts with underscore in variable name", {
-    expect_message(result_list <- dummy_df |>
-           any_table(rows    = "age",
-                     columns = "first_person",
-                     values  = weight,
-                     print   = FALSE), " X ERROR: No underscores allowed in column variable names")
-})
-
-
 test_that("any_table aborts with invalid by variable", {
     expect_message(result_list <- dummy_df |>
            any_table(rows    = "age",
@@ -473,12 +466,25 @@ test_that("any_table aborts with value variable having too many underscores in p
 })
 
 
-test_that("any_table aborts with column variable having underscores", {
-    dummy_df[["to_many_underscores"]] <- 1
+test_that("Combine tables into a single workbook", {
+    my_style <- excel_output_style(sheet_name = "tab1")
 
-    expect_message(result_list <- dummy_df |>
-                       any_table(rows       = "age",
-                                 columns    = "to_many_underscores",
-                                 values     = weight,
-                                 print      = FALSE), " X ERROR: No underscores allowed in column variable names. Execution will be aborted.")
+    tab1 <- suppressMessages(dummy_df |>
+                 any_table(rows    = "age",
+                           columns = "sex",
+                           values  = weight,
+                           print   = FALSE))
+
+    my_style <- my_style |> modify_output_style(sheet_name = "tab2")
+
+    tab2 <- suppressMessages(dummy_df |>
+                 any_table(rows    = "age",
+                           columns = "sex",
+                           values  = weight,
+                           by      = education,
+                           print   = FALSE))
+
+    result <- combine_into_workbook(tab1, tab2, print = FALSE)
+
+    expect_type(result, "environment")
 })
